@@ -4,7 +4,7 @@ use serde_json;
 
 pub struct Config {
     _host: String,
-    _port: String
+    _port: i32 
 }
 
 impl Config { 
@@ -17,12 +17,12 @@ impl Config {
 
     pub fn host(&self) -> &String { &self._host }
 
-    pub fn port(&self) -> &String { &self._port }
+    pub fn port(&self) -> i32 { self._port }
 }
 
 #[derive(Serialize, Deserialize, Debug)]
 struct ConfigDto {
     host: String,
-    port: String
+    port: i32, 
 }
 
